#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CTZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CTZ_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/ctz.hpp>

#endif
